# WebPageInfo

Web page information (title, content, tags…)

Internal tool, no public documentation…

## Commands

### Publish

First, update version number in pyproject.toml

Then:

```
hatch build
hatch publish
```

### Launch test

```
hatch run dev:test
```

## TODO

- specific exeception instead of ValueError
